DGIpy |version|
=========================

.. image:: https://img.shields.io/pypi/v/dgipy.svg
   :alt: PyPI version
   :target: https://pypi.python.org/pypi/dgipy

.. image:: https://img.shields.io/pypi/l/dgipy.svg
   :alt: License
   :target: https://github.com/genomicmedlab/dgipy/blob/main/LICENSE

.. image:: https://img.shields.io/pypi/pyversions/dgipy?color=gr
   :alt: PyPI - supported Python versions

.. image:: https://github.com/genomicmedlab/dgipy/actions/workflows/checks.yaml/badge.svg
   :alt: tests status
   :target: https://github.com/genomicmedlab/dgipy/actions/workflows/checks.yaml

Python wrapper for accessing an instance of DGIdb v5 database

.. toctree::
   :hidden:
   :maxdepth: 2

    Installation<install>
    Changelog<changelog>
    Contributing<contributing>
    License<license>
